/* 
 * Copyright © 2008-2011 Kristian Høgsberg
 * Copyright © 2010-2011 Intel Corporation
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 * 
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 */

#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

extern const struct wl_interface wl_object_interface;
extern const struct wl_interface wl_callback_interface;
extern const struct wl_interface wl_object_interface;
extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface wl_buffer_interface;
extern const struct wl_interface wl_data_source_interface;
extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface wl_buffer_interface;
extern const struct wl_interface wl_data_source_interface;
extern const struct wl_interface wl_data_offer_interface;
extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface wl_data_offer_interface;
extern const struct wl_interface wl_data_offer_interface;
extern const struct wl_interface wl_data_source_interface;
extern const struct wl_interface wl_data_device_interface;
extern const struct wl_interface wl_input_device_interface;
extern const struct wl_interface wl_shell_surface_interface;
extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface wl_input_device_interface;
extern const struct wl_interface wl_input_device_interface;
extern const struct wl_interface wl_shell_surface_interface;
extern const struct wl_interface wl_input_device_interface;
extern const struct wl_interface wl_shell_surface_interface;
extern const struct wl_interface wl_buffer_interface;
extern const struct wl_interface wl_callback_interface;
extern const struct wl_interface wl_buffer_interface;
extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface wl_surface_interface;

static const struct wl_interface *types[] = {
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_callback_interface,
	NULL,
	NULL,
	NULL,
	&wl_surface_interface,
	&wl_buffer_interface,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_data_source_interface,
	&wl_surface_interface,
	NULL,
	NULL,
	&wl_buffer_interface,
	NULL,
	NULL,
	&wl_data_source_interface,
	NULL,
	&wl_data_offer_interface,
	NULL,
	&wl_surface_interface,
	NULL,
	NULL,
	&wl_data_offer_interface,
	&wl_data_offer_interface,
	&wl_data_source_interface,
	&wl_data_device_interface,
	&wl_input_device_interface,
	&wl_shell_surface_interface,
	&wl_surface_interface,
	&wl_input_device_interface,
	NULL,
	&wl_input_device_interface,
	NULL,
	NULL,
	&wl_shell_surface_interface,
	NULL,
	NULL,
	NULL,
	&wl_input_device_interface,
	NULL,
	&wl_shell_surface_interface,
	NULL,
	NULL,
	NULL,
	&wl_buffer_interface,
	NULL,
	NULL,
	&wl_callback_interface,
	NULL,
	&wl_buffer_interface,
	NULL,
	NULL,
	NULL,
	&wl_surface_interface,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_surface_interface,
	NULL,
	NULL,
	&wl_surface_interface,
	NULL,
	NULL,
	NULL,
};

static const struct wl_message wl_display_requests[] = {
	{ "bind", "usun", types + 7 },
	{ "sync", "n", types + 11 },
};

static const struct wl_message wl_display_events[] = {
	{ "error", "ous", types + 12 },
	{ "global", "usu", types + 0 },
	{ "global_remove", "u", types + 0 },
	{ "delete_id", "u", types + 0 },
};

WL_EXPORT const struct wl_interface wl_display_interface = {
	"wl_display", 1,
	ARRAY_LENGTH(wl_display_requests), wl_display_requests,
	ARRAY_LENGTH(wl_display_events), wl_display_events,
};

static const struct wl_message wl_callback_events[] = {
	{ "done", "u", types + 0 },
};

WL_EXPORT const struct wl_interface wl_callback_interface = {
	"wl_callback", 1,
	0, NULL,
	ARRAY_LENGTH(wl_callback_events), wl_callback_events,
};

static const struct wl_message wl_compositor_requests[] = {
	{ "create_surface", "n", types + 15 },
};

WL_EXPORT const struct wl_interface wl_compositor_interface = {
	"wl_compositor", 1,
	ARRAY_LENGTH(wl_compositor_requests), wl_compositor_requests,
	0, NULL,
};

static const struct wl_message wl_shm_requests[] = {
	{ "create_buffer", "nhiiuu", types + 16 },
};

static const struct wl_message wl_shm_events[] = {
	{ "format", "u", types + 0 },
};

WL_EXPORT const struct wl_interface wl_shm_interface = {
	"wl_shm", 1,
	ARRAY_LENGTH(wl_shm_requests), wl_shm_requests,
	ARRAY_LENGTH(wl_shm_events), wl_shm_events,
};

static const struct wl_message wl_buffer_requests[] = {
	{ "damage", "iiii", types + 0 },
	{ "destroy", "", types + 0 },
};

static const struct wl_message wl_buffer_events[] = {
	{ "release", "", types + 0 },
};

WL_EXPORT const struct wl_interface wl_buffer_interface = {
	"wl_buffer", 1,
	ARRAY_LENGTH(wl_buffer_requests), wl_buffer_requests,
	ARRAY_LENGTH(wl_buffer_events), wl_buffer_events,
};

static const struct wl_message wl_data_offer_requests[] = {
	{ "accept", "us", types + 0 },
	{ "receive", "sh", types + 0 },
	{ "destroy", "", types + 0 },
};

static const struct wl_message wl_data_offer_events[] = {
	{ "offer", "s", types + 0 },
};

WL_EXPORT const struct wl_interface wl_data_offer_interface = {
	"wl_data_offer", 1,
	ARRAY_LENGTH(wl_data_offer_requests), wl_data_offer_requests,
	ARRAY_LENGTH(wl_data_offer_events), wl_data_offer_events,
};

static const struct wl_message wl_data_source_requests[] = {
	{ "offer", "s", types + 0 },
	{ "destroy", "", types + 0 },
};

static const struct wl_message wl_data_source_events[] = {
	{ "target", "s", types + 0 },
	{ "send", "sh", types + 0 },
	{ "cancelled", "", types + 0 },
};

WL_EXPORT const struct wl_interface wl_data_source_interface = {
	"wl_data_source", 1,
	ARRAY_LENGTH(wl_data_source_requests), wl_data_source_requests,
	ARRAY_LENGTH(wl_data_source_events), wl_data_source_events,
};

static const struct wl_message wl_data_device_requests[] = {
	{ "start_drag", "oou", types + 22 },
	{ "attach", "uoii", types + 25 },
	{ "set_selection", "ou", types + 29 },
};

static const struct wl_message wl_data_device_events[] = {
	{ "data_offer", "n", types + 31 },
	{ "enter", "uoiio", types + 32 },
	{ "leave", "", types + 0 },
	{ "motion", "uii", types + 0 },
	{ "drop", "", types + 0 },
	{ "selection", "o", types + 37 },
};

WL_EXPORT const struct wl_interface wl_data_device_interface = {
	"wl_data_device", 1,
	ARRAY_LENGTH(wl_data_device_requests), wl_data_device_requests,
	ARRAY_LENGTH(wl_data_device_events), wl_data_device_events,
};

static const struct wl_message wl_data_device_manager_requests[] = {
	{ "create_data_source", "n", types + 38 },
	{ "get_data_device", "no", types + 39 },
};

WL_EXPORT const struct wl_interface wl_data_device_manager_interface = {
	"wl_data_device_manager", 1,
	ARRAY_LENGTH(wl_data_device_manager_requests), wl_data_device_manager_requests,
	0, NULL,
};

static const struct wl_message wl_shell_requests[] = {
	{ "get_shell_surface", "no", types + 41 },
};

WL_EXPORT const struct wl_interface wl_shell_interface = {
	"wl_shell", 1,
	ARRAY_LENGTH(wl_shell_requests), wl_shell_requests,
	0, NULL,
};

static const struct wl_message wl_shell_surface_requests[] = {
	{ "move", "ou", types + 43 },
	{ "resize", "ouu", types + 45 },
	{ "set_toplevel", "", types + 0 },
	{ "set_transient", "oiiu", types + 48 },
	{ "set_fullscreen", "", types + 0 },
	{ "set_popup", "ouoiiu", types + 52 },
};

static const struct wl_message wl_shell_surface_events[] = {
	{ "configure", "uuii", types + 0 },
	{ "popup_done", "", types + 0 },
};

WL_EXPORT const struct wl_interface wl_shell_surface_interface = {
	"wl_shell_surface", 1,
	ARRAY_LENGTH(wl_shell_surface_requests), wl_shell_surface_requests,
	ARRAY_LENGTH(wl_shell_surface_events), wl_shell_surface_events,
};

static const struct wl_message wl_surface_requests[] = {
	{ "destroy", "", types + 0 },
	{ "attach", "oii", types + 58 },
	{ "damage", "iiii", types + 0 },
	{ "frame", "n", types + 61 },
};

WL_EXPORT const struct wl_interface wl_surface_interface = {
	"wl_surface", 1,
	ARRAY_LENGTH(wl_surface_requests), wl_surface_requests,
	0, NULL,
};

static const struct wl_message wl_input_device_requests[] = {
	{ "attach", "uoii", types + 62 },
};

static const struct wl_message wl_input_device_events[] = {
	{ "motion", "uiiii", types + 0 },
	{ "button", "uuu", types + 0 },
	{ "key", "uuu", types + 0 },
	{ "pointer_focus", "uoiiii", types + 66 },
	{ "keyboard_focus", "uoa", types + 72 },
	{ "touch_down", "uoiii", types + 75 },
	{ "touch_up", "ui", types + 0 },
	{ "touch_motion", "uiii", types + 0 },
	{ "touch_frame", "", types + 0 },
	{ "touch_cancel", "", types + 0 },
};

WL_EXPORT const struct wl_interface wl_input_device_interface = {
	"wl_input_device", 1,
	ARRAY_LENGTH(wl_input_device_requests), wl_input_device_requests,
	ARRAY_LENGTH(wl_input_device_events), wl_input_device_events,
};

static const struct wl_message wl_output_events[] = {
	{ "geometry", "iiiiiss", types + 0 },
	{ "mode", "uiii", types + 0 },
};

WL_EXPORT const struct wl_interface wl_output_interface = {
	"wl_output", 1,
	0, NULL,
	ARRAY_LENGTH(wl_output_events), wl_output_events,
};

